@@ -73,6 +73,7 @@ pub struct Config {
     pub uda_style_calendar_title: Style,
     pub uda_style_calendar_today: Style,
     pub uda_style_report_completion_pane: Style,
+    pub uda_style_report_completion_pane_highlight: Style,
     pub uda_shortcuts: Vec<String>,
     pub uda_background_process: String,
     pub uda_background_process_period: usize,
@@ -127,6 +128,7 @@ impl Config {
         let uda_style_calendar_today = Self::get_uda_style("calendar.today", data);
         let uda_style_context_active = Self::get_uda_style("context.active", data);
         let uda_style_report_completion_pane = Self::get_uda_style("report.completion-pane", data);
+        let uda_style_report_completion_pane_highlight = Self::get_uda_style("report.completion-pane-highlight", data);
         let uda_shortcuts = Self::get_uda_shortcuts(data);
         let uda_background_process = Self::get_uda_background_process(data);
         let uda_background_process_period = Self::get_uda_background_process_period(data);
@@ -139,6 +141,8 @@ impl Config {
         let uda_style_context_active = uda_style_context_active.unwrap_or_default();
         let uda_style_report_completion_pane =
             uda_style_report_completion_pane.unwrap_or_else(|| Style::default().bg(Color::Rgb(223, 223, 223)));
+        let uda_style_report_completion_pane_highlight =
+            uda_style_report_completion_pane_highlight.unwrap_or(uda_style_report_completion_pane);
         let uda_quick_tag_name = Self::get_uda_quick_tag_name(data);
         let uda_task_report_prompt_on_delete = Self::get_uda_task_report_prompt_on_delete(data);
         let uda_task_report_prompt_on_done = Self::get_uda_task_report_prompt_on_done(data);
@@ -179,6 +183,7 @@ impl Config {
             uda_style_calendar_title,
             uda_style_calendar_today,
             uda_style_report_completion_pane,
+            uda_style_report_completion_pane_highlight,
             uda_style_report_scrollbar,
             uda_shortcuts,
             uda_background_process,
