@@ -19,6 +19,7 @@ pub struct KeyConfig {
     pub delete: Key,
     pub done: Key,
     pub start_stop: Key,
+    pub quick_tag: Key,
     pub select: Key,
     pub select_all: Key,
     pub undo: Key,
@@ -60,6 +61,7 @@ impl Default for KeyConfig {
             delete: Key::Char('x'),
             done: Key::Char('d'),
             start_stop: Key::Char('s'),
+            quick_tag: Key::Char('t'),
             select: Key::Char('v'),
             select_all: Key::Char('V'),
             undo: Key::Char('u'),
@@ -108,6 +110,7 @@ impl KeyConfig {
         let delete = Self::get_config("uda.taskwarrior-tui.keyconfig.delete", data);
         let done = Self::get_config("uda.taskwarrior-tui.keyconfig.done", data);
         let start_stop = Self::get_config("uda.taskwarrior-tui.keyconfig.start-stop", data);
+        let quick_tag = Self::get_config("uda.taskwarrior-tui.keyconfig.quick-tag", data);
         let select = Self::get_config("uda.taskwarrior-tui.keyconfig.select", data);
         let select_all = Self::get_config("uda.taskwarrior-tui.keyconfig.select-all", data);
         let undo = Self::get_config("uda.taskwarrior-tui.keyconfig.undo", data);
@@ -134,6 +137,7 @@ impl KeyConfig {
         self.delete = delete.unwrap_or(self.delete);
         self.done = done.unwrap_or(self.done);
         self.start_stop = start_stop.unwrap_or(self.start_stop);
+        self.quick_tag = quick_tag.unwrap_or(self.quick_tag);
         self.select = select.unwrap_or(self.select);
         self.select_all = select_all.unwrap_or(self.select_all);
         self.undo = undo.unwrap_or(self.undo);
@@ -167,6 +171,7 @@ impl KeyConfig {
             &self.select,
             &self.select_all,
             &self.start_stop,
+            &self.quick_tag,
             &self.undo,
             &self.edit,
             &self.modify,
